Simple tests
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/lsm303dlh_mag_simpletest.py
    :caption: examples/lsm303dlh_mag_simpletest.py
    :linenos:

.. literalinclude:: ../examples/lsm303dlh_mag_fast.py
    :caption: examples/lsm303dlh_mag_fast.py
    :linenos:
